import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { MongooseModule } from '@nestjs/mongoose';
import Configuration from './config/configuration';
import { VersioningModule } from './versioning/versioning.module';
import { PerformanceModule } from './performance/performance.module';

@Module({
  imports: [
    ConfigModule.forRoot({
      load: [Configuration],
      isGlobal: true,
    }),
    MongooseModule.forRootAsync({
      imports: [ConfigModule],
      inject: [ConfigService],
      useFactory: async (config: ConfigService) => ({
        uri: `mongodb://${config.get<string>(
          'database.host',
        )}:${config.get<number>('database.port')}/${config.get<string>(
          'database.name',
        )}`,
      }),
    }),
    VersioningModule,
    PerformanceModule,
  ],
})
export class AppModule {}
